@@ -1,6 +1,6 @@
 from gooey import Gooey, GooeyParser
 from .comFunction import get_list
-from .mainflow.main_process import main_process
+from .main_process import main_process
 
 
 @Gooey(
